# brawlpython

[![PyPi][pypi img]][pypi link]
![Supported Versions][versions img]
[![License][license img]][license link]
[![Wheel][wheel img]][wheel link]
[![Say Thanks!][thanks img]][thanks link]


Easy-to-configure library to use any Brawl Stars API

[Source on github][github link]

Documentation coming soon


[pypi img]: https://img.shields.io/pypi/v/brawlpython.svg?style=plastic
[thanks img]: https://img.shields.io/badge/Say%20Thanks-!-1EAEDB.svg?style=plastic
[license img]: https://img.shields.io/pypi/l/brawlpython?style=plastic
[versions img]: https://img.shields.io/pypi/pyversions/brawlpython.svg?style=plastic
[wheel img]: https://img.shields.io/pypi/wheel/brawlpython?style=plastic

[pypi link]: https://pypi.org/project/brawlpython
[thanks link]: https://saythanks.io/to/0dminnimda@gmail.com
[license link]: https://github.com/0dminnimda/brawlpython/blob/master/LICENSE
[wheel link]: https://pypi.org/project/brawlpython/#files
[github link]: https://github.com/0dminnimda/brawlpython
